/*
 * Snake.c
 *
 * Created: 5/22/2018 4:56:58 PM
 * Author : alex
 */ 

#define F_CPU 16000000
#include <avr/io.h>
#include <stdio.h>
#include <stdint.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include "spi.h"
#include "ST7735R_TFT.h"
#include "game.h"
#define Xchannel	5
/*
 * Functia initializeaza convertorul Analog-Digital.
 */
void ADC_init(void)
{
    ADMUX = (1 << REFS0);
    ADCSRA = (1 << ADEN) | (5 << ADPS0);
}

void IO_init(void)
{
	/* Setare Buzzer */

	DDRD &= ~(1 << PD6);

	/* Activez rezistenta de pull-up */
	PORTD |= (1 << PD6);

	/* Setez pinul PD0 ca iesire buzzer */
	DDRD |= (1 << PD0);

	/* Opresc buzzer-ul. */
	PORTD &= ~(1 << PD0);
}

/*
 * Functia porneste o noua conversie pentru canalul precizat.
 * In modul fara intreruperi, apelul functiei este blocant. Aceasta se
 * intoarce cand conversia este finalizata.
 *
 * In modul cu intreruperi apelul NU este blocant.
 *
 * @return Valoarea numerica raw citita de ADC de pe canlul specificat.
 */
uint16_t ADC_get(uint8_t channel)
{
    ADMUX = (ADMUX & ~(0x1f << MUX0)) | channel;

    ADCSRA |= (1 << ADSC);
    while(ADCSRA & (1 << ADSC));

    return ADC;
}

int main(void)
{
	int xval;
	int yval;

    // Init ADC.
    ADC_init();
	
	IO_init();
	
	// Init SPI
    SPI_init();

    // Init LCD
    ST7735R_Begin();
	
    // Clear screen with BLACK.
	ST7735R_FillRect(0, 0, ST7735R_WIDTH - 1, ST7735R_HEIGHT - 1, 0, 0, 0);
	
    GAME_init();
    _delay_ms(200);

    for(;;)
    {
			xval = ADC_get(5) - 512;
			yval = ADC_get(6) - 512;
            GAME_move_snake(xval / 64, yval / 64);

            GAME_loop();

			int buzz  = GAME_buzz_delay();
			int boost = GAME_boost();

			if (buzz == 0 && boost == 0)
				_delay_ms(160);
			else if (buzz == 1 && boost == 0)
				_delay_ms(50);
			else if (buzz == 1 && boost == 1)
				_delay_ms(50);
			else if (buzz == 0 && boost == 1)
				_delay_ms(80);

    }

    return 0;
}

